@@ -15,7 +15,7 @@ from invoke import Collection  # noqa, re-export
 from fh_fablib.extract_js_gettext_strings import generate_strings
 
 
-__version__ = "1.0.20220315"
+__version__ = "1.0.20220324"
 
 
 # I don't care, in this context.
@@ -232,6 +232,37 @@ def reset_pw(ctx):
     )
 
 
+@task
+def reset_sq(ctx):
+    """Reset all PostgreSQL sequences"""
+
+    SQL = """
+SELECT 'SELECT SETVAL(' ||
+       quote_literal(quote_ident(PGT.schemaname) || '.' || quote_ident(S.relname)) ||
+       ', COALESCE(MAX(' ||quote_ident(C.attname)|| '), 1) ) FROM ' ||
+       quote_ident(PGT.schemaname)|| '.'||quote_ident(T.relname)|| ';'
+FROM pg_class AS S,
+     pg_depend AS D,
+     pg_class AS T,
+     pg_attribute AS C,
+     pg_tables AS PGT
+WHERE S.relkind = 'S'
+    AND S.oid = D.objid
+    AND D.refobjid = T.oid
+    AND D.refobjid = C.attrelid
+    AND D.refobjsubid = C.attnum
+    AND T.relname = PGT.tablename
+ORDER BY S.relname;
+    """
+
+    dsn = _local_env()("DATABASE_URL")
+
+    with tempfile.NamedTemporaryFile("w") as f:
+        f.write(SQL)
+        f.seek(0)
+        ctx.run(f"psql -Atq -f {f.name} {dsn} | psql -a {dsn}")
+
+
 def _local_env(path=".env"):
     mapping = {}
     speckenv.read_speckenv(config.base / path, mapping=mapping)
@@ -288,7 +319,7 @@ def cm(ctx):
 
 
 def _python3():
-    interpreters = ("python3.9", "python3.8", "python3.7", "python3.6")
+    interpreters = ("python3.10", "python3.9", "python3.8")
     return next(filter(None, (shutil.which(v) for v in interpreters)))
 
 
@@ -327,6 +358,7 @@ def update(ctx):
         run(ctx, f"{_python3()} -m venv venv")
     _pip_up(ctx)
     run(ctx, "venv/bin/python -m pip install -r requirements.txt")
+    run(ctx, "git submodule update --init")
     run(ctx, 'find . -name "*.pyc" -delete')
     run(ctx, "yarn")
     run(ctx, "venv/bin/python manage.py migrate", warn=True)
@@ -703,6 +735,7 @@ def _deploy_django(conn):
         terminate("Terminating because of uncommitted changes on server")
 
     run(conn, f"git reset --hard origin/{config.branch}")
+    run(conn, "git submodule update --init")
     run(conn, 'find . -name "*.pyc" -delete')
     _pip_up(conn)
     run(conn, "venv/bin/python -m pip install -r requirements.txt")
@@ -756,6 +789,7 @@ GENERAL = {
     pull_db,
     pull_media,
     reset_pw,
+    reset_sq,
     local,
     bitbucket,
     github,
